@@ -47,6 +47,7 @@ typedef struct conversion_info_struct
     int num_dimensions;
     harp_dimension_type dimension_type[HARP_MAX_NUM_DIMS];
     uint8_t *skip;      /* 1: variable cannot be created; 2: variable cannot be used because of cyclic dependency */
+    int8_t product_contains_species[harp_num_chemical_species]; /* -1: not set, 0: no, 1: maybe */
     int depth;
     int max_depth;
     harp_variable *variable;
@@ -96,6 +97,24 @@ static int has_dimension_types(const harp_variable *variable, int num_dimensions
     return 1;
 }
 
+/* 0: definitely not, 1: maybe */
+static int product_has_species(const harp_product *product, harp_chemical_species species)
+{
+    const char *species_name = harp_chemical_species_name(species);
+    int i;
+
+    for (i = 0; i < product->num_variables; i++)
+    {
+        if (strstr(product->variable[i]->name, species_name) != NULL)
+        {
+            /* may not be an exact match, but mark as possible */
+            return 1;
+        }
+    }
+
+    return 0;
+}
+
 static char *get_dimsvar_name(const char *variable_name, int num_dimensions, const harp_dimension_type *dimension_type)
 {
     char *dimsvar_name;
@@ -169,6 +188,7 @@ static int conversion_info_init(conversion_info *info, const harp_product *produ
         return -1;
     }
     memset(info->skip, 0, harp_derived_variable_conversions->num_variables);
+    memset(info->product_contains_species, -1, harp_num_chemical_species);
 
     return 0;
 }
@@ -399,25 +419,27 @@ static int perform_conversion(conversion_info *info)
 static void print_source_variable(const harp_source_variable_definition *source_definition,
                                   int (*print)(const char *, ...), int indent);
 
-/* return: 0: possible, 1: not possible (no cycle), 2: not possible (cycle or out of budget) */
+/* return: 0: possible, 1: not possible (at all), 2: not possible (cycle), 3: not possible (out of budget) */
 static int find_source_variables(conversion_info *info, harp_source_variable_definition *source_definition,
                                  double total_budget, double *best_cost)
 {
     harp_variable *variable;
     harp_variable_conversion_list *conversion_list;
     harp_variable_conversion *best_conversion = NULL;
-    int has_cycle_or_oob = 0;   /* has cycle or out-of-budget */
+    int is_out_of_budget = 0;
+    int has_cycle = 0;
     int index;
     int i;
 
     if (total_budget < 0)
     {
-        return 2;
+        return 3;
     }
 
-    if (harp_product_get_variable_by_name(info->product, source_definition->variable_name, &variable) == 0)
+    if (harp_product_has_variable(info->product, source_definition->variable_name))
     {
-        if (has_dimension_types(variable, source_definition->num_dimensions, source_definition->dimension_type,
+        if (harp_product_get_variable_by_name(info->product, source_definition->variable_name, &variable) == 0 &&
+            has_dimension_types(variable, source_definition->num_dimensions, source_definition->dimension_type,
                                 source_definition->independent_dimension_length))
         {
             /* variable is present in the product */
@@ -428,14 +450,14 @@ static int find_source_variables(conversion_info *info, harp_source_variable_def
 
     if (total_budget < 1)
     {
-        return 2;
+        return 3;
     }
 
     /* if we are at the maximum search depth then bail out */
     if (info->depth == info->max_depth)
     {
-        /* treat this as a cycle (since we don't want to prevent further searches for this variable at lower depths) */
-        return 2;
+        /* treat this as an out-of-budget (since we want to allow further searches for this variable at lower depths) */
+        return 3;
     }
 
     /* try to find a conversion for the variable */
@@ -448,10 +470,34 @@ static int find_source_variables(conversion_info *info, harp_source_variable_def
     }
     if (info->skip[index])
     {
-        return 1 + (info->skip[index] == 2);
+        if (info->skip[index] == 2)
+        {
+            /* this is a cycle */
+            return 2;
+        }
+        return 1;
     }
 
     conversion_list = harp_derived_variable_conversions->conversions_for_variable[index];
+
+    if (conversion_list->specific_species != harp_chemical_species_unknown)
+    {
+        if (info->product_contains_species[conversion_list->specific_species] == -1)
+        {
+            /* initialize */
+            info->product_contains_species[conversion_list->specific_species] =
+                product_has_species(info->product, conversion_list->specific_species);
+        }
+        if (info->product_contains_species[conversion_list->specific_species] == 0)
+        {
+            /* permanently mark this variable as something that cannot be derived */
+            info->skip[index] = 1;
+
+            /* conversion not possible since no variables for the same species exist in the product */
+            return 1;
+        }
+    }
+
     for (i = 0; i < conversion_list->num_conversions; i++)
     {
         harp_variable_conversion *conversion = conversion_list->conversion[i];
@@ -490,9 +536,13 @@ static int find_source_variables(conversion_info *info, harp_source_variable_def
             if (result != 0)
             {
                 /* source not found */
-                if (result == 2)
+                if (result == 3)
                 {
-                    has_cycle_or_oob = 1;
+                    is_out_of_budget = 1;
+                }
+                else if (result == 2)
+                {
+                    has_cycle = 1;
                 }
                 break;
             }
@@ -519,14 +569,22 @@ static int find_source_variables(conversion_info *info, harp_source_variable_def
         return 0;
     }
 
-    if (!has_cycle_or_oob)
+    /* no conversion found */
+
+    if (is_out_of_budget)
     {
-        /* permanently mark this conversion as something that cannot be performed */
-        info->skip[index] = 1;
+        return 3;
     }
 
-    /* no conversion found */
-    return 1 + has_cycle_or_oob;
+    if (has_cycle)
+    {
+        return 2;
+    }
+
+    /* permanently mark this variable as something that cannot be derived */
+    info->skip[index] = 1;
+
+    return 1;
 }
 
 static int find_and_execute_conversion(conversion_info *info)
@@ -881,10 +939,11 @@ void harp_variable_conversion_delete(harp_variable_conversion *conversion)
 }
 
 /* this function also adds the conversion to the global derived variable conversion list */
-int harp_variable_conversion_new(const char *variable_name, harp_data_type data_type, const char *unit,
-                                 int num_dimensions, harp_dimension_type *dimension_type,
-                                 long independent_dimension_length, harp_conversion_function set_variable_data,
-                                 harp_variable_conversion **new_conversion)
+int harp_variable_conversion_species_new(const char *variable_name, harp_data_type data_type, const char *unit,
+                                         int num_dimensions, harp_dimension_type *dimension_type,
+                                         long independent_dimension_length, harp_chemical_species specific_species,
+                                         harp_conversion_function set_variable_data,
+                                         harp_variable_conversion **new_conversion)
 {
     harp_variable_conversion *conversion = NULL;
     int i;
@@ -911,6 +970,7 @@ int harp_variable_conversion_new(const char *variable_name, harp_data_type data_
     conversion->source_description = NULL;
     conversion->set_variable_data = set_variable_data;
     conversion->enabled = NULL;
+    conversion->specific_species = specific_species;
 
     conversion->dimsvar_name = get_dimsvar_name(variable_name, num_dimensions, dimension_type);
     if (conversion->dimsvar_name == NULL)
@@ -943,6 +1003,16 @@ int harp_variable_conversion_new(const char *variable_name, harp_data_type data_
     return 0;
 }
 
+int harp_variable_conversion_new(const char *variable_name, harp_data_type data_type, const char *unit,
+                                 int num_dimensions, harp_dimension_type *dimension_type,
+                                 long independent_dimension_length, harp_conversion_function set_variable_data,
+                                 harp_variable_conversion **new_conversion)
+{
+    return harp_variable_conversion_species_new(variable_name, data_type, unit, num_dimensions, dimension_type,
+                                                independent_dimension_length, harp_chemical_species_unknown,
+                                                set_variable_data, new_conversion);
+}
+
 int harp_variable_conversion_add_source(harp_variable_conversion *conversion, const char *variable_name,
                                         harp_data_type data_type, const char *unit, int num_dimensions,
                                         harp_dimension_type *dimension_type, long independent_dimension_length)
@@ -1096,19 +1166,33 @@ LIBHARP_API int harp_doc_list_conversions(const harp_product *product, const cha
     {
         harp_variable_conversion_list *conversion_list = harp_derived_variable_conversions->conversions_for_variable[i];
         harp_variable_conversion *best_conversion = NULL;
+        harp_variable_conversion *first_conversion;
+        harp_variable *variable;
         double best_cost;
 
         assert(conversion_list->num_conversions > 0);
 
-        if (variable_name != NULL && strcmp(conversion_list->conversion[0]->variable_name, variable_name) != 0)
+        first_conversion = conversion_list->conversion[0];
+
+        if (variable_name != NULL && strcmp(first_conversion->variable_name, variable_name) != 0)
         {
             continue;
         }
 
+        if (harp_product_has_variable(product, first_conversion->variable_name))
+        {
+            if (harp_product_get_variable_by_name(product, first_conversion->variable_name, &variable) == 0 &&
+                harp_variable_has_dimension_types(variable, first_conversion->num_dimensions,
+                                                  first_conversion->dimension_type))
+            {
+                /* variable with same dimensions already exists -> skip conversions for this variable */
+                continue;
+            }
+        }
+
         /* initialize based on first conversion in the list */
-        if (conversion_info_set_variable(&info, conversion_list->conversion[0]->variable_name,
-                                         conversion_list->conversion[0]->num_dimensions,
-                                         conversion_list->conversion[0]->dimension_type) != 0)
+        if (conversion_info_set_variable(&info, first_conversion->variable_name, first_conversion->num_dimensions,
+                                         first_conversion->dimension_type) != 0)
         {
             return -1;
         }
@@ -1118,7 +1202,6 @@ LIBHARP_API int harp_doc_list_conversions(const harp_product *product, const cha
         for (j = 0; j < conversion_list->num_conversions; j++)
         {
             harp_variable_conversion *conversion = conversion_list->conversion[j];
-            harp_variable *variable;
             double budget = best_conversion == NULL ? harp_plusinf() : best_cost;
             double total_cost = 0;
             int k;
@@ -1128,15 +1211,6 @@ LIBHARP_API int harp_doc_list_conversions(const harp_product *product, const cha
                 continue;
             }
 
-            if (harp_product_get_variable_by_name(product, conversion->variable_name, &variable) == 0)
-            {
-                if (harp_variable_has_dimension_types(variable, conversion->num_dimensions, conversion->dimension_type))
-                {
-                    /* variable with same dimensions already exists -> skip conversions for this variable */
-                    continue;
-                }
-            }
-
             for (k = 0; k < conversion->num_source_variables; k++)
             {
                 double cost;
