@@ -626,6 +626,29 @@ static int read_solar_elevation_angle_msi(void *user_data, harp_array data)
     return read_array_msi((ingest_info *)user_data, "solar_elevation_angle", harp_type_double, data);
 }
 
+static int read_solar_spectral_irradiance_msi(void *user_data, harp_array data)
+{
+    ingest_info *info = (ingest_info *)user_data;
+    long i, j;
+
+    if (read_array_partial(info->science_data_cursor, "solar_spectral_irradiance", harp_type_double,
+                           4 * info->num_across_track, info->msi_band * info->num_across_track, info->num_across_track,
+                           data) != 0)
+    {
+        return -1;
+    }
+
+    for (i = 1; i < info->num_along_track; i++)
+    {
+        for (j = 0; j < info->num_across_track; j++)
+        {
+            data.double_data[i * info->num_across_track + j] = data.double_data[j];
+        }
+    }
+
+    return 0;
+}
+
 static int read_time(void *user_data, harp_array data)
 {
     ingest_info *info = (ingest_info *)user_data;
@@ -854,7 +877,7 @@ static void register_atl_nom_1b_product(void)
     const char *options;
     const char *path;
 
-    description = "ATLID L1 Nominal product";
+    description = "ATLID L1 Nominal product (ESA)";
     module = harp_ingestion_register_module("ECA_ATL_NOM_1B", "EarthCARE", "EARTHCARE", "ATL_NOM_1B", description,
                                             ingestion_init, ingestion_done);
     harp_ingestion_register_option(module, "data", "the type of backscatter profile to ingest; option values are "
@@ -947,7 +970,7 @@ static void register_bbr_nom_1b_product(void)
     const char *options;
     const char *path;
 
-    description = "BBR L1 Nominal Product";
+    description = "BBR L1 Nominal Product (ESA)";
     module = harp_ingestion_register_module("ECA_BBR_NOM_1B", "EarthCARE", "EARTHCARE", "BBR_NOM_1B", description,
                                             ingestion_init, ingestion_done);
 
@@ -1094,7 +1117,7 @@ static void register_bbr_sng_1b_product(void)
     const char *description;
     const char *path;
 
-    description = "BBR L1 Single Pixel Product";
+    description = "BBR L1 Single Pixel Product (ESA)";
     module = harp_ingestion_register_module("ECA_BBR_SNG_1B", "EarthCARE", "EARTHCARE", "BBR_SNG_1B", description,
                                             ingestion_init, ingestion_done);
 
@@ -1207,7 +1230,7 @@ static void register_msi_nom_1b_product(void)
     const char *description;
     const char *path;
 
-    description = "MSI L1b Nominal Product";
+    description = "MSI L1b Nominal Product (ESA)";
     module = harp_ingestion_register_module("ECA_MSI_NOM_1B", "EarthCARE", "EARTHCARE", "MSI_NOM_1B", description,
                                             ingestion_init, ingestion_done);
 
@@ -1277,9 +1300,9 @@ static void register_msi_nom_1b_product(void)
     path = "/ScienceData/sensor_elevation_angle[<band>,*,*]";
     harp_variable_definition_add_mapping(variable_definition, NULL, NULL, path, band_description);
 
-    /* radiance */
+    /* wavelength_radiance */
     variable_definition =
-        harp_ingestion_register_variable_full_read(product_definition, "radiance", harp_type_double, 1,
+        harp_ingestion_register_variable_full_read(product_definition, "wavelength_radiance", harp_type_double, 1,
                                                    dimension_type, NULL, "radiance", "W/m2/sr/um", include_radiance_msi,
                                                    read_pixel_values_msi);
     path = "/ScienceData/pixel_values[<band>,*,*]";
@@ -1287,6 +1310,16 @@ static void register_msi_nom_1b_product(void)
     harp_variable_definition_add_mapping(variable_definition, NULL, "band=VIS, band=VNIR, band=SWIR1, band=SWIR2", path,
                                          description);
 
+    /* wavelength_irradiance */
+    variable_definition =
+        harp_ingestion_register_variable_full_read(product_definition, "wavelength_irradiance", harp_type_double, 1,
+                                                   dimension_type, NULL, "solar spectral irradiance", "W/m2/um",
+                                                   include_radiance_msi, read_solar_spectral_irradiance_msi);
+    path = "/ScienceData/solar_spectral_irradiance[<band>,*]";
+    description = "<band> is 0 (VIS), 1 (VNIR), 2 (SWIR1), or 3 (SWIR2); data is replicated for all scanlines";
+    harp_variable_definition_add_mapping(variable_definition, NULL, "band=VIS, band=VNIR, band=SWIR1, band=SWIR2", path,
+                                         description);
+
     /* brightness_temperature */
     variable_definition =
         harp_ingestion_register_variable_full_read(product_definition, "brightness_temperature", harp_type_double, 1,
