@@ -1362,6 +1362,14 @@ static int execute_point_filter(ingest_info *info, harp_program *program)
         harp_variable_delete(longitude);
         return -1;
     }
+    if (harp_variable_convert_data_type(latitude, harp_type_double) != 0)
+    {
+        return -1;
+    }
+    if (harp_variable_convert_data_type(longitude, harp_type_double) != 0)
+    {
+        return -1;
+    }
 
     if (latitude->num_dimensions == 0)
     {
@@ -1519,6 +1527,14 @@ static int execute_polygon_filter(ingest_info *info, harp_program *program)
         harp_variable_delete(longitude_bounds);
         return -1;
     }
+    if (harp_variable_convert_data_type(latitude_bounds, harp_type_double) != 0)
+    {
+        return -1;
+    }
+    if (harp_variable_convert_data_type(longitude_bounds, harp_type_double) != 0)
+    {
+        return -1;
+    }
 
     if (latitude_bounds->num_dimensions == 0 || latitude_bounds->dimension_type[0] != harp_dimension_time)
     {
